summaryrefslogtreecommitdiffstats
path: root/lib/Fetcher/IFeedFetcher.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Fetcher/IFeedFetcher.php')
-rw-r--r--lib/Fetcher/IFeedFetcher.php4
1 files changed, 3 insertions, 1 deletions
diff --git a/lib/Fetcher/IFeedFetcher.php b/lib/Fetcher/IFeedFetcher.php
index ecc0ffc16..81bf8526f 100644
--- a/lib/Fetcher/IFeedFetcher.php
+++ b/lib/Fetcher/IFeedFetcher.php
@@ -13,6 +13,8 @@
namespace OCA\News\Fetcher;
+use FeedIo\Reader\ReadErrorException;
+
interface IFeedFetcher
{
@@ -28,7 +30,7 @@ interface IFeedFetcher
*
* @return array an array containing the new feed and its items, first
* element being the Feed and second element being an array of Items
* @throws FetcherException if the fetcher encounters a problem
*/
public function fetch(string $url, bool $favicon, $lastModified, $user, $password): array;
@@ -28,7 +30,7 @@ interface IFeedFetcher
* @return array an array containing the new feed and its items, first
* element being the Feed and second element being an array of Items
- * @throws FetcherException if the fetcher encounters a problem
+ * @throws ReadErrorException if the Feed-IO fetcher encounters a problem
*/
public function fetch(string $url, bool $favicon, $lastModified, $user, $password): array;